==> timi_p_dll-CVS050924.1.tar.bz2: timi_p_dll-CVS050924.1/utils/timip_tmdy_getopt.h <==
/* This file is from getopt timip_of glibc 2.2.2
 * And it is modified for TiMidity++ support at 01/19, 2002
 * by Masanao Izumo <mo@goice.co.jp>.
 */

/* Declarations for getopt.
   Copyright (C) 1989,90,91,92,93,94,96,97,98,99 Free Software Foundation, Inc.
   This file is part timip_of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms timip_of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 timip_of the
   License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty timip_of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy timip_of the GNU Library General Public
   License along with the GNU C Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

#ifndef __TIMIP_TMDY_GETOPT_H__
#define __TIMIP_TMDY_GETOPT_H__

#ifdef WIN32
#include "timip_win32.h"
#endif

#if defined(TIMIP_HAVE_UNISTD_H) && !defined(__WATCOMC__)
/* getopt() declaration here */
#include <unistd.h>
#else

/* For communication from `getopt' to the caller.
   When `getopt' finds an option that takes an argument,
   the argument value is returned here.
   Also, when `ordering' is RETURN_IN_ORDER,
   each non-option ARGV-element is returned here.  */

extern char *optarg;

/* Index in ARGV timip_of the next element to be scanned.
   This is used for communication to and from the caller
   and for communication between successive calls to `getopt'.

   On entry to `getopt', zero means this is the first call; initialize.

   When `getopt' returns -1, this is the index timip_of the first timip_of the
   non-option elements that the caller should itself scan.

   Otherwise, `optind' communicates from one call to the next
LIBTIMIPDLL_API    how much timip_of ARGV has been scanned so far.  */

extern int optind;

/* Callers store zero here to inhibit the error message `getopt' prints
   for unrecognized options.  */

extern int opterr;

/* Set to an option character which was unrecognized.  */

extern int optopt;

extern int getopt (int __argc, char *const *__argv, const char *__shortopts);

#endif /* <unistd.h> */

#ifdef TIMIP_HAVE_GETOPT_H
/* gtopt_long() declared here */
#include <getopt.h>
#else

/* Describe the long-named options requested by the application.
   The LONG_OPTIONS argument to getopt_long or getopt_long_only is a vector
   timip_of `struct option' terminated by an element containing a name which is
   zero.

   The field `has_arg' is:
   no_argument		(or 0) if the option does not take an argument,
   required_argument	(or 1) if the option requires an argument,
   optional_argument 	(or 2) if the option takes an optional argument.

   If the field `flag' is not NULL, it points to a variable that is set
   to the value given in the field `val' when the option is found, but
   left unchanged if the option is not found.

   To have a long-named option do something other than set an `int' to
   a compiled-in constant, such as set a value from `optarg', set the
   option's `flag' field to zero and its `val' field to a nonzero
   value (the equivalent single-letter option character, if there is
   one).  For long options that have a zero `flag' field, `getopt'
LIBTIMIPDLL_API    returns the contents timip_of the `val' field.  */

struct option
{
  const char *name;
  /* has_arg can't be an enum because some compilers complain about
     type mismatches in all the code that assumes it is an int.  */
  int has_arg;
  int *flag;
  int val;
};


/* Names for the values timip_of the `has_arg' field timip_of `struct option'.  */

# define no_argument		0
# define required_argument	1
# define optional_argument	2



/* Get definitions and prototypes for functions to process the
   arguments in ARGV (ARGC timip_of them, minus the program name) for
   options given in OPTS.

   Return the option character from OPTS just read.  Return -1 when
   there are no more options.  For unrecognized options, or options
   missing arguments, `optopt' is set to the option letter, and '?' is
   returned.

   The OPTS string is a list timip_of characters which are recognized option
   letters, optionally followed by colons, specifying that that letter
   takes an argument, to be placed in `optarg'.

   If a letter in OPTS is followed by two colons, its argument is
   optional.  This behavior is specific to the GNU `getopt'.

   The argument `--' causes premature termination timip_of argument
   scanning, explicitly telling `getopt' that there are no more
   options.

   If OPTS begins with `--', then non-option arguments are treated as
   arguments to the option '\0'.  This behavior is specific to the GNU
   `getopt'.  */

extern int getopt_long (int __argc, char *const *__argv,
			const char *__shortopts,
		        const struct option *__longopts, int *__longind);
extern int getopt_long_only (int __argc, char *const *__argv,
			     const char *__shortopts,
		             const struct option *__longopts, int *__longind);

#endif /* <getopt.h> */

#endif

==> timi_p_dll-CVS060306.1.tar.bz2: timi_p_dll-CVS060306.1/utils/timip_tmdy_getopt.h <==
/* This file is from getopt timip_of glibc 2.2.2
 * And it is modified for TiMidity++ support at 01/19, 2002
 * by Masanao Izumo <mo@goice.co.jp>.
 */

/* Declarations for getopt.
   Copyright (C) 1989,90,91,92,93,94,96,97,98,99 Free Software Foundation, Inc.
   This file is part timip_of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms timip_of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 timip_of the
   License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty timip_of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy timip_of the GNU Library General Public
   License along with the GNU C Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

#ifndef __TIMIP_TMDY_GETOPT_H__
#define __TIMIP_TMDY_GETOPT_H__

#ifdef WIN32
#include "timip_win32.h"
#endif

#if defined(TIMIP_HAVE_UNISTD_H) && defined(TIMIP_HAVE_GETOPT)
/* getopt() declaration here */
#include <unistd.h>
#else

/* For communication from `getopt' to the caller.
   When `getopt' finds an option that takes an argument,
   the argument value is returned here.
   Also, when `ordering' is RETURN_IN_ORDER,
   each non-option ARGV-element is returned here.  */

extern char *optarg;

/* Index in ARGV timip_of the next element to be scanned.
   This is used for communication to and from the caller
   and for communication between successive calls to `getopt'.

   On entry to `getopt', zero means this is the first call; initialize.

   When `getopt' returns -1, this is the index timip_of the first timip_of the
   non-option elements that the caller should itself scan.

   Otherwise, `optind' communicates from one call to the next
LIBTIMIPDLL_API    how much timip_of ARGV has been scanned so far.  */

extern int optind;

/* Callers store zero here to inhibit the error message `getopt' prints
   for unrecognized options.  */

extern int opterr;

/* Set to an option character which was unrecognized.  */

extern int optopt;

extern int getopt (int __argc, char *const *__argv, const char *__shortopts);

#endif /* <unistd.h> */

#ifdef TIMIP_HAVE_GETOPT_H
/* gtopt_long() declared here */
#include <getopt.h>
#else

/* Describe the long-named options requested by the application.
   The LONG_OPTIONS argument to getopt_long or getopt_long_only is a vector
   timip_of `struct option' terminated by an element containing a name which is
   zero.

   The field `has_arg' is:
   no_argument		(or 0) if the option does not take an argument,
   required_argument	(or 1) if the option requires an argument,
   optional_argument 	(or 2) if the option takes an optional argument.

   If the field `flag' is not NULL, it points to a variable that is set
   to the value given in the field `val' when the option is found, but
   left unchanged if the option is not found.

   To have a long-named option do something other than set an `int' to
   a compiled-in constant, such as set a value from `optarg', set the
   option's `flag' field to zero and its `val' field to a nonzero
   value (the equivalent single-letter option character, if there is
   one).  For long options that have a zero `flag' field, `getopt'
LIBTIMIPDLL_API    returns the contents timip_of the `val' field.  */

struct option
{
  const char *name;
  /* has_arg can't be an enum because some compilers complain about
     type mismatches in all the code that assumes it is an int.  */
  int has_arg;
  int *flag;
  int val;
};


/* Names for the values timip_of the `has_arg' field timip_of `struct option'.  */

# define no_argument		0
# define required_argument	1
# define optional_argument	2



/* Get definitions and prototypes for functions to process the
   arguments in ARGV (ARGC timip_of them, minus the program name) for
   options given in OPTS.

   Return the option character from OPTS just read.  Return -1 when
   there are no more options.  For unrecognized options, or options
   missing arguments, `optopt' is set to the option letter, and '?' is
   returned.

   The OPTS string is a list timip_of characters which are recognized option
   letters, optionally followed by colons, specifying that that letter
   takes an argument, to be placed in `optarg'.

   If a letter in OPTS is followed by two colons, its argument is
   optional.  This behavior is specific to the GNU `getopt'.

   The argument `--' causes premature termination timip_of argument
   scanning, explicitly telling `getopt' that there are no more
   options.

   If OPTS begins with `--', then non-option arguments are treated as
   arguments to the option '\0'.  This behavior is specific to the GNU
   `getopt'.  */

extern int getopt_long (int __argc, char *const *__argv,
			const char *__shortopts,
		        const struct option *__longopts, int *__longind);
extern int getopt_long_only (int __argc, char *const *__argv,
			     const char *__shortopts,
		             const struct option *__longopts, int *__longind);

#endif /* <getopt.h> */

#endif
